[DebianGIS-dev] r1842 - scripts

2009-01-14 Thread camerons-guest
Author: camerons-guest
Date: 2009-01-14 10:50:00 + (Wed, 14 Jan 2009)
New Revision: 1842

Modified:
   scripts/dgis-status.pl
Log:
Now includes a -u option to display table as ubuntu - plus a number of other 
tweaks

Modified: scripts/dgis-status.pl
===
--- scripts/dgis-packages.inc   2009-01-04 14:47:10 UTC (rev 1839)
+++ scripts/dgis-packages.inc   2009-01-06 20:25:03 UTC (rev 1840)
@@ -42,7 +42,7 @@
 'gpx2shp' = {url='http://gpx2shp.sourceforge.jp/'},
 'grace' = {url='ftp://plasma-gate.weizmann.ac.il/pub/grace/src/'},
 'grace6' = {url='ftp://plasma-gate.weizmann.ac.il/pub/grace/src/'},
-'grass' = {url='http://grass.itc.it/'},
+'grass' = {url='http://grass.osgeo.org/'},
 'gts' = {url='http://gts.sourceforge.net/'},
 'gvsig' = {url='http://www.gvsig.gva.es'},
 'ircmarkers' = {url='http://www.df7cb.de/projects/ircmarkers/'},


___
Pkg-grass-devel mailing list
Pkg-grass-devel@lists.alioth.debian.org
http://lists.alioth.debian.org/mailman/listinfo/pkg-grass-devel
--- scripts/dgis-status.pl  2009-01-14 10:30:54 UTC (rev 1841)
+++ scripts/dgis-status.pl  2009-01-14 10:50:00 UTC (rev 1842)
@@ -1,27 +1,39 @@
 #!/usr/bin/perl
 #
 #  dgis-status.pl - DebianGis packages status script 
 #
-#  $Id$
-#  
-#  Copyright 2005-2007 (C) Francesco P. Lovergine fran...@debian.org
-#  
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#  
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#  
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  
USA
-#  
-#  On Debian GNU/Linux GPL is available under /usr/share/common-licenses
-#  
+#   $Id$
+#
+#   Copyright 2005-2007 (C) Francesco P. Lovergine fran...@debian.org
+#
+#   This program is free software; you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation; either version 2 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program; if not, write to the Free Software
+#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  
USA
+#
+#   On Debian GNU/Linux GPL is available under /usr/share/common-licenses
+#
+#   Installation:
+#   On a Debian based system,
+# apt-get install libsvn-perl libcache-apt-perl
+#
+#   Usage:
+# For available options type:
+# debian-status.pl -h
+#
+#   Authors:
+# Francesco P. Lovergine (original author of dgis-status.pl)
+# Cameron Shorter (extended to Ubuntu)
+#
 
 use strict 'vars';
 
@@ -33,73 +45,146 @@
 use AptPkg::System '$_system';
 use AptPkg::Version;
 
-getopts ('odhvf:');# -o option: only do difference (no wget)
-our($opt_o, $opt_h, $opt_v, $opt_b, $opt_c, $opt_d, $opt_f);
+getopts('odhuvf:');# -o option: only do difference (no wget)
+our ( $opt_o, $opt_h, $opt_u, $opt_v, $opt_b, $opt_c, $opt_d, $opt_f );
 
-push @INC, $ENV{'HOME'}./pkg-grass/scripts;
+#push @INC, $ENV{'HOME'}./pkg-grass/scripts;
+push @INC, $ENV{'HOME'} . work/ubuntugis/pkg-grass/scripts;
 
+#my $_stable   = fred;
+#my $_unstable = fred;
+#my $_ubuntu   = fred;
+#my $_testing  = fred;
 my $svn_repo = svn://svn.debian.org/pkg-grass;
 my $web_repo = http://svn.debian.org/wsvn/pkg-grass;;
 
 require dgis-packages.inc;
 
-my %wget  = ( 'quiet' = 'wget --passive-ftp --quiet -O ','verbose' = 
'wget --passive-ftp -O ' );
-my %gunzip= ( 'quiet' = 'gunzip --force --quiet ', 'verbose' = 'gunzip 
--force' );
-my %paths = (
-'stable'   = 
[http://ftp.nl.debian.org/debian/dists/stable/main/source/;,
-  
http://ftp.nl.debian.org/debian/dists/stable/non-free/source/;,
-  
http://ftp.it.debian.org/debian/dists/stable/contrib/source/;],
-'testing'  = 
[http://ftp.nl.debian.org/debian/dists/testing/main/source/;,
-  
http://ftp.nl.debian.org/debian/dists/testing/non-free/source/;,
-  
http://ftp.it.debian.org/debian/dists/testing/contrib/source/;],
-'unstable' = 
[http://ftp.nl.debian.org/debian/dists/unstable/main/source/;,
-  
http://ftp.nl.debian.org/debian/dists/unstable/non-free/source/;,
-  
http://ftp.it.debian.org/debian/dists/unstable/contrib/source/;],
-'bpo' =  
[http://www.backports.org/debian/dists/etch-backports/main/source/;,
-  
http://www.backports.org/debian/dists/etch-backports/non-free/source/;,
-  
http://www.backports.org/debian/dists/etch-backports/contrib/source/;],
+my %wget = (
+'quiet'   = 'wget --passive
@@ -1,27 +1,39 @@
 #!/usr/bin/perl
 #
-#  dgis-status.pl - DebianGis packages status script 
+#   dgis-status.pl - UbuntuGIS/DebianGis packages status script
 #

[DebianGIS-dev] r1840 - scripts

2009-01-06 Thread camerons-guest
Author: camerons-guest
Date: 2009-01-06 20:25:03 + (Tue, 06 Jan 2009)
New Revision: 1840

Modified:
   scripts/dgis-packages.inc
Log:
Changed upstream url for grass

Modified: scripts/dgis-packages.inc
===